==> php-residence_0.2.4.tar.gz: php-residence/contr/contr02.php <==
<?php

#################################################################################
#    PHP-RESIDENCE
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################

# CONTRATTO n 2

$contratto = "

<B><U><FONT FACE=\"Times\" SIZE=4><P ALIGN=\"CENTER\">EXAMPLE OF CONTRACT FOR PHP-RESIDENCE</P>
</U></B></FONT><FONT FACE=\"Times\"><P ALIGN=\"JUSTIFY\"></P>
<P ALIGN=\"JUSTIFY\">&nbsp;</P>

<P ALIGN=\"JUSTIFY\">
Mr$Mr $name $surname born the $birthday resident in $city $street2 n 
$street_number tel $telephone will rent an aparmetnt in php-residence
with his family of $people_num_tot people from $starting_date to $ending_date.
The price will be of $fare_tot_p. A deposit of $deposit_p must be left.
</P>
<P ALIGN=\"JUSTIFY\">
Nowhere, $oggi.
</P>
<P ALIGN=\"JUSTIFY\"></P>
<P ALIGN=\"JUSTIFY\">The 
client&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;The 
owner</P>
<P ALIGN=\"JUSTIFY\"></P>
<P ALIGN=\"JUSTIFY\"> 
__________&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;____________</P>

<P ALIGN=\"JUSTIFY\"></P>
</FONT></BODY>

";


?>

==> php-residence_0.4.3.tar.gz: php-residence/contr/contr02.php <==
<?php

#################################################################################
#    PHP-RESIDENCE
#    Copyright (C) 2001-2004 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################

# CONTRATTO n 2

$contratto = "

<B><U><FONT FACE=\"Times\" SIZE=4><P ALIGN=\"CENTER\">EXAMPLE OF CONTRACT FOR PHP-RESIDENCE</P>
</U></B></FONT><FONT FACE=\"Times\"><P ALIGN=\"JUSTIFY\"></P>
<P ALIGN=\"JUSTIFY\">&nbsp;</P>

<P ALIGN=\"JUSTIFY\">
Mr$Mr $name $surname born the $birthday resident in $city $street2 n 
$street_number tel $telephone will rent an apartment in php-residence
with his family of $people_num_tot people from $starting_date to $ending_date.
The price will be of $fare_tot_p. A deposit of $deposit_p must be left.
</P>
<P ALIGN=\"JUSTIFY\">
Nowhere, $oggi.
</P>
<P ALIGN=\"JUSTIFY\"></P>
<P ALIGN=\"JUSTIFY\">
The client
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
The owner</P>
<P ALIGN=\"JUSTIFY\"></P>
<P ALIGN=\"JUSTIFY\"> 
__________&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;____________</P>

<P ALIGN=\"JUSTIFY\"></P>
</FONT></BODY>

";


?>
